/*
    Roaminfo - RoamAbout Access Point Information
    Copyright (C) 2000 Greg Hankins <gregh@twoguys.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
*/

#include "snmp.h"

struct snmp_session session;   /* defaults */
struct snmp_session *sp;       /* session pointer */

/*
 * Initialize SNMP.
 */
int snmp_init(char *hostname, char *community) {

    init_snmp("snmpapp");

    /* setup session defaults */
    snmp_sess_init(&session);
    session.version = SNMP_VERSION_1;
    session.peername = hostname;
    session.community = community;
    session.community_len = strlen(session.community);

    return 0;
}

/*
 * Get SNMP responses.
 */
int snmp_get(char *request[], char *response[], int count) {

    struct snmp_pdu *request_pdu;         /* SNMP request PDU */
    struct snmp_pdu *response_pdu;        /* SNMP response PDU */
    oid my_oid[MAX_OID_LEN];              /* tmp OID */
    size_t my_oid_length = MAX_OID_LEN;   /* tmp OID */
    struct variable_list *vp;             /* pointer for variables */
    int status;                           /* request status */
    int i;                                /* tmp */

    /* open session */
    sp = snmp_open(&session);

    /* setup request PDU */
    request_pdu = snmp_pdu_create(SNMP_MSG_GET);
    for (i = 0; i < count; i++) {
        read_objid(request[i], my_oid, &my_oid_length); 
        snmp_add_null_var(request_pdu, my_oid, my_oid_length);
    }

    /* get response */
    status = snmp_synch_response(sp, request_pdu, &response_pdu);

    /* print variables in response */
    if (status == STAT_SUCCESS && response_pdu->errstat == SNMP_ERR_NOERROR) {
        i = 0;
        for (vp = response_pdu->variables; vp; vp = vp->next_variable) {
            if (response != NULL) {
                sprint_value(response[i], vp->name, vp->name_length, vp);
                i++;
            }
        }
    }

    /* cleanup */     
    snmp_free_pdu(response_pdu);
    snmp_close(sp);

    return(status);
} 

/*
 * Set SNMP variables.
 */
int snmp_set() {

    return 0;
     
}
